<?php
/**
 * @brief		SparkPost Email Class
 * @author		<a href='http://www.invisionpower.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) 2001 - 2016 Invision Power Services, Inc.
 * @license		http://www.invisionpower.com/legal/standards/
 * @package		IPS Community Suite
 * @since		17 Apr 2013
 * @version		SVN_VERSION_NUMBER
 */

namespace IPS\Email\Outgoing;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * SparkPost Email Class
 */
class _SparkPost extends \IPS\Email
{
	/**
	 * Send
	 *
	 * @return	bool
	 * @throws	\IPS\Email\Exception
	 */
	protected function _send()
	{		
		$recipientsForSparkpost = array();
		foreach ( $this->recipients as $address )
		{
			$recipientsForSparkpost[] = array( 'address' => array( 'email' => $address ) );
		}
		
		$response = \IPS\Email::sparkpost( 'transmissions', \IPS\Settings::i()->sparkpost_api_key, array(
			'recipients'		=> $recipientsForSparkpost,
			'content'			=> array(
				'html'				=> $this->emailBody['html'],
				'text'				=> $this->emailBody['plain'],
				'subject'			=> $this->subject,
				'from'				=> array(
					'email'				=> $this->from,
					'name'				=> $this->fromName
				)
			)
		) );
		
		if ( isset( $response['errors'] ) )
		{
			throw new \IPS\Email\Outgoing\Exception( $response['errors'][0]['message'], $response['errors'][0]['code'] );
		}
		
		return TRUE;
	}
}